python-gfshare
==============

.. image:: https://travis-ci.org/lamby/python-gfshare.svg?branch=master
    :target: https://travis-ci.org/lamby/python-gfshare

**Full documentation**: https://lamby.github.io/python-gfshare/

----

This Python library implements `Shamir's method for secret sharing
<https://en.wikipedia.org/wiki/Shamir%27s_Secret_Sharing>`__ which can be used
to split an arbitrary secret into multiple parts.

Please see the `full documentation <https://lamby.github.io/python-gfshare/>`__
for more details, usage examples, etc.
